@@ -10,21 +10,15 @@ use Types::Serialiser ();
 use XSLoader ();
 
 BEGIN {
-    $VERSION = '0.05_02';
-    XSLoader::load( __PACKAGE__, $VERSION );
+    $VERSION = '0.01';
+    XSLoader::load();
 }
 
 =encoding utf8
 
 =head1 NAME
 
-TOML::XS - Turbo-charged L<TOML|https://toml.io> parsing!
-
-=begin html
-
-<a href='https://coveralls.io/github/FGasper/p5-TOML-XS?branch=master'><img src='https://coveralls.io/repos/github/FGasper/p5-TOML-XS/badge.svg?branch=master' alt='Coverage Status' /></a>
-
-=end html
+TOML::XS - Parse L<TOML|https://toml.io> with XS
 
 =head1 SYNOPSIS
 
@@ -36,7 +30,7 @@ TOML::XS - Turbo-charged L<TOML|https://toml.io> parsing!
 =head1 DESCRIPTION
 
 This module facilitates parsing of TOML documents in Perl via XS,
-which can yield dramatic performance gains relative to pure-Perl TOML
+which can yield significant performance gains relative to pure-Perl TOML
 libraries.
 
 It is currently implemented as a wrapper around the
@@ -49,11 +43,6 @@ L<tomlc99|https://github.com/cktan/tomlc99> C library.
 Converts a byte string (i.e., raw, undecoded bytes) that contains a
 serialized TOML document to a L<TOML::XS::Document> instance.
 
-Throws a suitable exception if the TOML document is unparseable. This
-doesn’t necessarily mean that I<any> malformed TOML content triggers such
-an error; for example, if an individual data item is malformed but the
-document is otherwise valid, this may return successful.
-
 =head1 MAPPING TOML TO PERL
 
 Most TOML data items map naturally to Perl. The following details
@@ -73,27 +62,10 @@ L<Types::Serialiser>.
 
 =head1 NOTE ON CHARACTER DECODING
 
-This library mimics the default behaviour of popular JSON modules:
+This library mimics the default configuration of popular JSON modules:
 the TOML input to the parser is expected to be a byte string, while the
 strings that the parser outputs are character strings.
 
-=head1 PERFORMANCE
-
-On my system the included (I<very> simple!) benchmark outputs:
-
-    Including TOML::Tiny …
-
-    small …
-                Rate toml_tiny   toml_xs
-    toml_tiny  1009/s        --      -95%
-    toml_xs   21721/s     2053%        --
-
-    large …
-                (warning: too few iterations for a reliable count)
-              s/iter toml_tiny   toml_xs
-    toml_tiny   1.65        --      -93%
-    toml_xs    0.110     1400%        --
-
 =cut
 
 #----------------------------------------------------------------------
@@ -101,37 +73,14 @@ On my system the included (I<very> simple!) benchmark outputs:
 *true = *Types::Serialiser::true;
 *false = *Types::Serialiser::false;
 
-sub _croak_malformed_toml {
-    my $path_ar = shift;
-
-    return _croak_with_pointer('Malformed TOML value found!', $path_ar);
-}
-
-sub _croak_pointer_beyond_datum {
-    my $path_ar = shift;
-
-    return _croak_with_pointer('Can’t descend into non-container!', $path_ar);
-}
-
-sub _croak_with_pointer {
-    my ($msg, $path_ar) = @_;
-
-    die sprintf( "%s (JSON pointer: %s)", $msg, _BUILD_JSON_POINTER($path_ar) );
-}
-
-sub _BUILD_JSON_POINTER {
-    my $pieces_ar = shift;
-
-    my @pieces =  @$pieces_ar;
-
-    s<~><~0>g for @pieces;
-    s</><~1>g for @pieces;
-
-    return join('/', q<>, @pieces);
-}
-
 #----------------------------------------------------------------------
 
+=head1 PERFORMANCE
+
+For small- and medium-sized files this should be quite a bit faster
+than pure-Perl TOML parsers. With larger files the speed gains are more
+muted or even (??) reversed. (That’s an underlying issue with tomlc99.)
+
 =head1 COPYRIGHT & LICENSE
 
 Copyright 2021 Gasper Software Consulting. All rights reserved.
